@@ -4,8 +4,8 @@ from todoist_service.todoist_wrapper.todoist_api_wrapper import TodoistAPIWrappe
 
 def register_user(db: DB, access_token: str):
     doist = TodoistAPIWrapper(access_token)
-    user_id = str(doist.get_user_id())
-    user_name = str(doist.get_user_name())
+    user_id = doist.get_user_id()
+    user_name = doist.get_user_name()
 
     db.add_user(user_id=user_id, token=access_token, full_name=user_name)
     return access_token, user_id
